
#ifndef _C14_kl697_
#define _C14_kl697_

#ifdef __cplusplus
extern "C" {
#endif

extern void F266_2468(EIF_REFERENCE);
extern EIF_BOOLEAN F266_2469(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
extern void EIF_Minit697(void);

#ifdef __cplusplus
}
#endif

#endif
